Modules
=======

This package is compose of two modules:

- dwca: Main module with the functionality to read and write Darwin Core Archive files following the standard defined by the `Biodiversity Information Standards (TDWG) <https://www.tdwg.org/>`_.
- eml: Module to read and write Ecological Metadata Language (``.eml``). This is the recommended format for the metadata attribute of the DwCA.
- xml_common: Module with util functionalities across all library.

.. toctree::
   :maxdepth: 4

   dwca
   eml
   xml_common
